@@ -2,7 +2,7 @@ from __future__ import annotations
 import os
 
 import asyncio
-from functools import partial
+import platform
 from typing import Any, Callable, ClassVar, Type, TypeVar
 import warnings
 
@@ -24,13 +24,14 @@ from ._context import active_app
 from ._event_broker import extract_handler_actions, NoHandler
 from .driver import Driver
 from .layouts.dock import DockLayout, Dock
-from ._linux_driver import LinuxDriver
 from .message_pump import MessagePump
 from ._profile import timer
 from .view import View
 from .views import DockView
-from .widget import Widget, Widget, Reactive
+from .widget import Widget, Reactive
 
+PLATFORM = platform.system()
+WINDOWS = PLATFORM == "Windows"
 
 # asyncio will warn against resources not being cleared
 warnings.simplefilter("always", ResourceWarning)
@@ -60,7 +61,6 @@ class App(MessagePump):
 
     def __init__(
         self,
-        console: Console | None = None,
         screen: bool = True,
         driver_class: Type[Driver] | None = None,
         log: str = "",
@@ -75,10 +75,10 @@ class App(MessagePump):
             driver_class (Type[Driver], optional): Driver class, or None to use default. Defaults to None.
             title (str, optional): Title of the application. Defaults to "Textual Application".
         """
-        self.console = console or Console()
+        self.console = Console()
         self.error_console = Console(stderr=True)
         self._screen = screen
-        self.driver_class = driver_class or LinuxDriver
+        self.driver_class = driver_class or self.get_driver_class()
         self._title = title
         self._layout = DockLayout()
         self._view_stack: list[DockView] = []
@@ -110,6 +110,24 @@ class App(MessagePump):
     sub_title: Reactive[str] = Reactive("")
     background: Reactive[str] = Reactive("black")
 
+    def get_driver_class(self) -> Type[Driver]:
+        """Get a driver class for this platform.
+
+        Called by the constructor.
+
+        Returns:
+            Driver: A Driver class which manages input and display.
+        """
+        if WINDOWS:
+            from .drivers.windows_driver import WindowsDriver
+
+            driver_class = WindowsDriver
+        else:
+            from .drivers.linux_driver import LinuxDriver
+
+            driver_class = LinuxDriver
+        return driver_class
+
     def __rich_repr__(self) -> rich.repr.Result:
         yield "title", self.title
 
@@ -182,7 +200,7 @@ class App(MessagePump):
         """
 
         async def run_app() -> None:
-            app = cls(console=console, screen=screen, driver_class=driver, **kwargs)
+            app = cls(screen=screen, driver_class=driver, **kwargs)
             await app.process_messages()
 
         asyncio.run(run_app())
@@ -284,6 +302,7 @@ class App(MessagePump):
             self.console.print_exception()
         else:
             try:
+                self.console = Console()
                 self.title = self._title
                 self.refresh()
                 await self.animator.start()
@@ -326,7 +345,9 @@ class App(MessagePump):
         await self.close_messages()
 
     def refresh(self, repaint: bool = True, layout: bool = False) -> None:
-        sync_available = os.environ.get("TERM_PROGRAM", "") != "Apple_Terminal"
+        sync_available = (
+            os.environ.get("TERM_PROGRAM", "") != "Apple_Terminal" and not WINDOWS
+        )
         if not self._closed:
             console = self.console
             try:
@@ -394,7 +415,7 @@ class App(MessagePump):
 
     async def on_event(self, event: events.Event) -> None:
         # Handle input events that haven't been forwarded
-        # If the event has been forwaded it may have bubbled up back to the App
+        # If the event has been forwarded it may have bubbled up back to the App
         if isinstance(event, events.InputEvent) and not event.is_forwarded:
             if isinstance(event, events.MouseEvent):
                 # Record current mouse position on App
