@@ -7,15 +7,13 @@ from abc import ABC, abstractmethod
 from typing import TYPE_CHECKING
 
 from . import events
+from . import log
 from ._types import MessageTarget
 
 if TYPE_CHECKING:
     from rich.console import Console
 
 
-WINDOWS = platform.system() == "Windows"
-
-
 class Driver(ABC):
     def __init__(self, console: "Console", target: "MessageTarget") -> None:
         self.console = console
